@@ -19,12 +19,16 @@ except:
 import hildon
 import osso
 import conic
+import dbus
 
 from gnome import gconf
 import threading
 
+gtkrunning = False
+
 #Class for running rdesktop-cli threads
 class rdpThread(threading.Thread) :
+	global gtkrunning
 	def __init__(self, name, host, parameters):
 		self.parameters = parameters
 		self.host = host
@@ -55,9 +59,11 @@ class rdpThread(threading.Thread) :
 		#print "rdesktop-cli " + self.parameters + " " + self.host
 		result = os.system("rdesktop-cli " + self.parameters + " " + self.host)
 		needEnter = False
-		for thread in threading.enumerate():
-			if thread.getName() == "gtk":
-				needEnter = True
+		#for thread in threading.enumerate():
+		#	if thread.getName() == "gtk":
+		#		needEnter = True
+		if gtkrunning == True :
+			needEnter = True
 		if needEnter == True :
 			gtk.gdk.threads_enter()
 		if result == 512 : #This isn't actually an error, just a connection closed weird...
@@ -369,6 +375,7 @@ class rdesktop:
 		# But that's ok, because we don't need to do anything with it!
 
 	def cancel(self,widget) :
+		print "quitting @ cancel...?"
 		if self.current_profile != "" :
 			self.client.set_string("/apps/rdesktop/load_prof", self.current_profile)
 		gtk.main_quit()
@@ -459,9 +466,14 @@ if __name__ == "__main__":
 	handle = rdesktop()
 	#bus = dbus.SystemBus(private=True)
 	gtk.gdk.threads_init()
-	threading.Thread(target=startGTK,name="gtk").start()
+	#threading.Thread(target=startGTK,name="gtk").start()
+	gtkrunning = True
+	gtk.main()
+	gtkrunning = False
 	#while threading.activeCount() > 1:
 		#for thread in threading.enumerate():
 			#print thread.getName()
 	#	time.sleep(1)
 	#sys.exit(1)
+	time.sleep(1)
+	print "Quitting... ?"
